@@ -112,3 +112,11 @@ def gamma(z):
     with np.errstate(divide='ignore'):
         return np.sum(
             np.power(x, z - 1) * np.power(math.e, -x) * dx, axis=axis_delta)
+
+
+def is_nan(x):
+    return x != x
+
+
+def is_not_nan(x):
+    return x == x
