@@ -75,7 +75,7 @@ class MixamoBot:
                 self.driver.find_element_by_name('email').send_keys(email)
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the "email" box')
                 time.sleep(1)
         self.driver.find_element_by_name('firstname').send_keys(first_name)
@@ -106,7 +106,7 @@ class MixamoBot:
                 self.driver.find_element_by_xpath("//a[contains(., 'Log in')]").click()
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the "Log in" button')
                 time.sleep(1)
 
@@ -118,7 +118,7 @@ class MixamoBot:
                 job_done = True
 
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the "username" box')
                 time.sleep(1)
 
@@ -133,7 +133,7 @@ class MixamoBot:
                 job_done = True
                 time.sleep(0.2)
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the "password" box')
                 time.sleep(1)
 
@@ -142,7 +142,6 @@ class MixamoBot:
 
         time.sleep(40)
 
-
     def activate_character(self, name_character, websites_search_actors):
 
         timer = cc_clock.Timer()
@@ -152,7 +151,7 @@ class MixamoBot:
                 current_actor_element = self.driver.find_element_by_css_selector('h2.text-center.h5')
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the name of the active character')
                 time.sleep(1)
         current_actor_name = current_actor_element.text
@@ -167,7 +166,7 @@ class MixamoBot:
                     self.driver.find_element_by_xpath("//p[contains(., '{}')]".format(name_character)).click()
                     job_done = True
                 except exceptions.NoSuchElementException:
-                    if timer.get_time() > self.timeout:
+                    if timer.get_seconds() > self.timeout:
                         raise TimeoutError('I cannot find the character box')
                     time.sleep(1)
 
@@ -178,13 +177,12 @@ class MixamoBot:
                     self.driver.find_element_by_xpath("//button[contains(., 'Use this character')]").click()
                     job_done = True
                 except exceptions.NoSuchElementException:
-                    if timer.get_time() > self.timeout:
+                    if timer.get_seconds() > self.timeout:
                         raise TimeoutError('I cannot find the "Use this character" button')
                     time.sleep(1)
             # search_box.clear()
             time.sleep(30)
 
-
     def activate_character_old(self, name_character, search_actor_as):
 
         timer = cc_clock.Timer()
@@ -194,7 +192,7 @@ class MixamoBot:
                 current_actor_element = self.driver.find_element_by_css_selector('h2.text-center.h5')
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the name of the active character')
                 time.sleep(1)
         current_actor_name = current_actor_element.text
@@ -208,7 +206,7 @@ class MixamoBot:
                     self.driver.find_element_by_name('search').send_keys(search_actor_as + keys.Keys.ENTER)
                     job_done = True
                 except exceptions.NoSuchElementException:
-                    if timer.get_time() > self.timeout:
+                    if timer.get_seconds() > self.timeout:
                         raise TimeoutError('I cannot find the "search" box')
                     time.sleep(1)
 
@@ -219,7 +217,7 @@ class MixamoBot:
                     self.driver.find_element_by_xpath("//p[contains(., '{}')]".format(name_character)).click()
                     job_done = True
                 except exceptions.NoSuchElementException:
-                    if timer.get_time() > self.timeout:
+                    if timer.get_seconds() > self.timeout:
                         raise TimeoutError('I cannot find the character box')
                     time.sleep(1)
 
@@ -230,7 +228,7 @@ class MixamoBot:
                     self.driver.find_element_by_xpath("//button[contains(., 'Use this character')]").click()
                     job_done = True
                 except exceptions.NoSuchElementException:
-                    if timer.get_time() > self.timeout:
+                    if timer.get_seconds() > self.timeout:
                         raise TimeoutError('I cannot find the "Use this character" button')
                     time.sleep(1)
             # search_box.clear()
@@ -245,7 +243,7 @@ class MixamoBot:
         n_animation_elements_from_web = len(elements_animations)
         while n_animation_elements_from_web != n_search_results_expected:
 
-            if timer.get_time() > self.timeout:
+            if timer.get_seconds() > self.timeout:
                 raise ValueError(
                     'The following condition is not met:\n'
                     'n_animation_elements_from_web = n_search_results_expected\n'
@@ -268,8 +266,8 @@ class MixamoBot:
 
         while n_frames_default_from_web != n_frames_default_expected:
 
-            if timer.get_time() > self.timeout:
-                print(timer.get_time())
+            if timer.get_seconds() > self.timeout:
+                print(timer.get_seconds())
                 raise ValueError(
                     'The following condition is not met:\n'
                     'n_frames_default_from_web = n_frames_default[i_animation]\n'
@@ -280,7 +278,7 @@ class MixamoBot:
                 text_total_frames = self.driver.find_element_by_xpath("//small[contains(., 'total frames')]").text
             except exceptions.NoSuchElementException:
                 time.sleep(1)
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot get the n_frames_default_from_web')
                 else:
                     continue
@@ -306,7 +304,7 @@ class MixamoBot:
                 n_frames_from_web_old = n_frames_from_web
             except exceptions.NoSuchElementException:
                 time.sleep(2)
-                if timer.get_time() > time_out:
+                if timer.get_seconds() > time_out:
                     raise TimeoutError('I cannot get the n_frames_from_web')
                 else:
                     continue
@@ -324,7 +322,6 @@ class MixamoBot:
 
         return n_frames_from_web
 
-
     def set_animation_parameters(self, parameters, elements_variables_mixamo=None):
         if elements_variables_mixamo is None:
             elements_variables_mixamo = self.driver.find_elements_by_css_selector(
@@ -415,7 +412,7 @@ class MixamoBot:
                 menus = self.driver.find_elements_by_id('formControlsSelect')
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the downloading menus')
                 time.sleep(1)
 
@@ -467,7 +464,7 @@ class MixamoBot:
                 menus = self.driver.find_elements_by_id('formControlsSelect')
                 job_done = True
             except exceptions.NoSuchElementException:
-                if timer.get_time() > self.timeout:
+                if timer.get_seconds() > self.timeout:
                     raise TimeoutError('I cannot find the downloading menus')
                 time.sleep(1)
 
@@ -492,7 +489,7 @@ class MixamoBot:
 
         timer = cc_clock.Timer()
         while n_fbx_to_rename != 1:
-            if timer.get_time() > timeout_dowloading:
+            if timer.get_seconds() > timeout_dowloading:
                 raise TimeoutError('actor was not downloaded')
             list_fbx_to_rename = glob.glob(os.path.join(self.directory_downloads, '*.fbx'))
             n_fbx_to_rename = len(list_fbx_to_rename)
