@@ -1,9 +1,8 @@
 import numpy as np
-from ccalafiore.array import samples_in_arr1_are_in_arr2
-from ccalafiore.preprocessing.variables_table_to_axes.balanced_or_unbalanced import (
-    from_2_arrays as v2a_from_2_arrays)
-# from ccalafiore.preprocessing.variables_table_to_axes.balanced import from_2_arrays as v2a_balanced_from_2_arrays
-# from ccalafiore.preprocessing.variables_table_to_axes.unbalanced import from_2_arrays as v2a_unbalanced_from_2_arrays
+from ...array import samples_in_arr1_are_in_arr2
+from .balanced_or_unbalanced import from_2_arrays as v2a_from_2_arrays
+# from .balanced import from_2_arrays as v2a_balanced_from_2_arrays
+# from .unbalanced import from_2_arrays as v2a_unbalanced_from_2_arrays
 
 
 def from_3_arrays(
@@ -469,7 +468,7 @@ def from_3_arrays_advanced(
             array_variables_adding_axes_balanced,
             axis_samples_input,
             axis_variables_table_input,
-            axes_inserting=axes_inserting_array_not_object,
+            axes_inserting_output=axes_inserting_array_not_object,
             balance=True,
             dtype=dtype,
             format_and_check=False)
@@ -479,7 +478,7 @@ def from_3_arrays_advanced(
             array_variables_adding_axes_balanced,
             axis_samples_input,
             axis_variables_table_input,
-            axes_inserting=axes_inserting_array_not_object,
+            axes_inserting_output=axes_inserting_array_not_object,
             balance=True,
             dtype=None,
             format_and_check=False)
@@ -492,7 +491,7 @@ def from_3_arrays_advanced(
             array_variables_adding_axes_unbalanced,
             axis_samples_input,
             axis_variables_table_input,
-            axes_inserting=axes_inserting_array_object,
+            axes_inserting_output=axes_inserting_array_object,
             balance=False,
             dtype=None,
             format_and_check=False)
