@@ -2,7 +2,7 @@ import numpy as np
 from scipy.stats import t
 # from scipy.stats.stats import _ttest_finish
 from ..combinations import n_conditions_to_combinations, trials_to_n_conditions
-from ..array import samples_in_arr1_are_in_arr2
+from .. import array as cc_array
 from .. import maths as cc_maths
 
 
@@ -164,7 +164,7 @@ def scores_to_n_samples(scores, axis_samples, keepdims=False, exclude_nan=True):
     return n_samples
 
 
-def samples_to_frequencies(data, axis_samples, axis_variables_table):
+def samples_to_frequencies(data, axis_samples, axis_variables_table, exclude_values=False, values=-1):
 
     if axis_samples < axis_variables_table:
         axis_comb = 0
@@ -186,7 +186,8 @@ def samples_to_frequencies(data, axis_samples, axis_variables_table):
     indexes_data[:] = slice(None)
     indexes_data[axes_other_data] = 0
 
-    n_conditions = trials_to_n_conditions(data[tuple(indexes_data)], axis_combinations=axis_comb)
+    n_conditions = trials_to_n_conditions(
+        data[tuple(indexes_data)], axis_combinations=axis_comb, exclude_values=exclude_values, values=values)
 
     n_axes_frequencies = n_axes_other_data + n_variables_table
     shape_frequencies = np.empty(n_axes_frequencies, dtype=int)
@@ -194,7 +195,7 @@ def samples_to_frequencies(data, axis_samples, axis_variables_table):
     shape_frequencies[slice(n_axes_other_data, n_axes_frequencies)] = n_conditions
     frequencies = np.empty(shape_frequencies, dtype=int)
     frequencies[:] = 0
-    indexes_frequencies = np.empty(n_axes_data, dtype=object)
+    indexes_frequencies = np.empty(n_axes_frequencies, dtype=object)
 
     combinations_others_and_samples = n_conditions_to_combinations(shape_data[axes_others_and_samples])
     # combinations_others = combinations_others_and_samples[slice(None), axes_others_and_samples != axis_samples]
@@ -202,11 +203,16 @@ def samples_to_frequencies(data, axis_samples, axis_variables_table):
     for comb_c in combinations_others_and_samples:
 
         indexes_data[axes_others_and_samples] = comb_c
-
-        indexes_frequencies[slice(n_axes_other_data)] = comb_c[indexes_comb_c]
-        indexes_frequencies[slice(n_axes_other_data, n_axes_frequencies)] = data[tuple(indexes_data)]
-
-        frequencies[tuple(indexes_frequencies)] += 1
+        data_c = data[tuple(indexes_data)]
+        if exclude_values:
+            if all(cc_array.samples_in_arr1_are_not_in_arr2(data_c, values)):
+                indexes_frequencies[slice(n_axes_other_data)] = comb_c[indexes_comb_c]
+                indexes_frequencies[slice(n_axes_other_data, n_axes_frequencies)] = data_c
+                frequencies[tuple(indexes_frequencies)] += 1
+        else:
+            indexes_frequencies[slice(n_axes_other_data)] = comb_c[indexes_comb_c]
+            indexes_frequencies[slice(n_axes_other_data, n_axes_frequencies)] = data_c
+            frequencies[tuple(indexes_frequencies)] += 1
 
     return frequencies
 
@@ -278,7 +284,7 @@ def scores_to_means(scores, axes, keepdims=False, exclude_nan=True):
             shape_scores_tmp[axes_means] = 1
         else:
             axes_scores = np.arange(n_axes_scores)
-            shape_scores_tmp = shape_scores[np.logical_not(samples_in_arr1_are_in_arr2(
+            shape_scores_tmp = shape_scores[np.logical_not(cc_array.samples_in_arr1_are_in_arr2(
                 axes_scores, axes_means))]
 
         shape_means = np.append(shape_object_scores, shape_scores_tmp)
