@@ -4,7 +4,7 @@ import os
 import glob
 from . import array as cc_array
 from . import directory as cc_directory
-from . import format_args as cc_format_args
+from . import format as cc_format
 from . import combinations as cc_combinations
 
 
@@ -66,7 +66,7 @@ def csv_file_to_array(filename, rows, columns, dtype=None):
         reader = csv.reader(csvfile, delimiter=',')
         table = np.asarray(list(reader), dtype=dtype)
 
-    indexes = tuple(cc_format_args.numeric_indexes_to_slice([rows, columns]))
+    indexes = tuple(cc_format.numeric_indexes_to_slice([rows, columns]))
     array = table[indexes]
 
     return array
@@ -117,7 +117,7 @@ def csv_file_to_arrays(filename, rows, columns, dtype=None):
     n_axes_per_text = 2
     arrays = [None] * n_arrays
     for a in range(n_arrays):
-        indexes = tuple(cc_format_args.numeric_indexes_to_slice([rows[a], columns[a]]))
+        indexes = tuple(cc_format.numeric_indexes_to_slice([rows[a], columns[a]]))
         if (dtype[a] is None) or (dtype[a] == str) or ('U' in dtype[a][:3]):
             arrays[a] = table[indexes]
         else:
@@ -178,7 +178,7 @@ def conditions_of_csv_files_to_arrays(conditions_of_directories, rows, columns,
     indexes = [None] * n_arrays  # type: list
     arrays = [None] * n_arrays  # type: list
     for a in range(n_arrays):
-        indexes[a] = tuple(cc_format_args.numeric_indexes_to_slice([rows[a], columns[a]]))
+        indexes[a] = tuple(cc_format.numeric_indexes_to_slice([rows[a], columns[a]]))
 
     directory_csv_d = os.path.join(*[
         conditions_of_directories[i][0] for i in range(n_axes_directories)])
